@@ -39,6 +39,8 @@ class Hardware(BaseHardware):
     self.antenna_labels = ('Ant 0', 'Ant 1')	# labels for the antenna button
     self.antenna_index = 0			# index of antenna in use
     self.delay_config = 30			# Delay sending message to HL2 until after sound starts
+    self.TFRC_counter = 0		# Call for power etc. at intervals
+    self.key_was_down = 0
     try:
       self.repeater_delay = conf.repeater_delay		# delay for changing repeater frequency in seconds
     except:
@@ -65,6 +67,15 @@ class Hardware(BaseHardware):
     #    C0 is a six-bit address. If the address is OR'd with 0x40, an ACK must be received or the item is re-transmitted.
     #    The item sent to the HL2 is C0<<1 | MoxBit.
     #    Sound must be started before you can use pc2hermeswritequeue.
+    # General I2C bus Access:
+    # Address C0 = 0x3c writes to the I2C bus 1. Use C0 = 0x7c to request an ACK.
+    # Address C0 = 0x3d writes to the I2C bus 2. Use C0 = 0x7d to request an ACK.
+    # Read requests must use the ACK.
+    #    self.pc2hermeslitewritequeue[0:5] = C0, C1, C2, C3, C4
+    #    C1 = 0x06 to write, 0x07 to read
+    #    C2 = 7-bit I2C address | stop;  Where "stop" is 0x80 to stop at end; else zero for continue
+    #    C3 = 8-bit I2C control (often a register address)
+    #    C4 = 8-bit I2C data for write, else 0
     self.pc2hermeslitewritequeue = bytearray(4 * 5)	# Four of (C0, C1, C2, C3, C4)
     # Initialize some data
     self.pc2hermes[3] = 0x04	# C0 index == 0, C4[5:3]: number of receivers 0b000 -> one receiver; C4[2] duplex on
@@ -340,13 +351,21 @@ class Hardware(BaseHardware):
   def ReturnFrequency(self):	# Return the current tuning and VFO frequency
     return None, None			# frequencies have not changed
   def HeartBeat(self):
-    self.hermes_temperature, self.hermes_fwd_power, self.hermes_rev_power, self.hermes_pa_current = QS.get_hermes_TFRC()
-    if self.application.bottom_widgets:
-      self.application.bottom_widgets.UpdateText()
+    self.TFRC_counter += 1
+    key_down = QS.is_key_down()
+    if key_down and not self.key_was_down:	# reset on key down
+      self.TFRC_counter = 0
+      QS.get_hermes_TFRC()
+    self.key_was_down = key_down
+    if self.TFRC_counter >= 3:
+      self.TFRC_counter = 0
+      self.hermes_temperature, self.hermes_fwd_power, self.hermes_rev_power, self.hermes_pa_current, self.hermes_fwd_peak, self.hermes_rev_peak = QS.get_hermes_TFRC()
+      if self.application.bottom_widgets:
+        self.application.bottom_widgets.UpdateText()
     if self.delay_config > 0:
       self.delay_config -= 1
       if self.delay_config == 0:	# Delay sending these config parameters
-        for name in ('hermes_disable_watchdog', 'hermes_reset_on_disconnect'):
+        for name in ('hermes_disable_watchdog', 'hermes_reset_on_disconnect', 'TheBand'):
           self.ImmediateChange(name)
   def RepeaterOffset(self, offset=None):	# Change frequency for repeater offset during Tx
     if offset is None:		# Return True if frequency change is complete
@@ -369,6 +388,8 @@ class Hardware(BaseHardware):
     self.band = band
     self.ChangeBandFilters()
     self.SetTxLevel()
+    if self.delay_config == 0:
+      self.ImmediateChange('TheBand')
   def OnButtonAntenna(self, event):
     btn = event.GetEventObject()
     self.antenna_index = btn.index
@@ -628,6 +649,13 @@ class Hardware(BaseHardware):
       self.ChangeBandFilters()
     elif name == 'hermes_antenna_tuner':
       pass
+    elif name == 'TheBand':
+      pass
+      #try:
+      #  band_num = self.conf.BandList.index(self.band) + 1
+      #except:
+      #  band_num = 0
+      #self.WriteI2C(0x7d, 0x1D, 0, band_num)		# Send band number to IO Board
     else:
       if DEBUG: print ("Immediate change: no such name", name)
   def EnableBiasChange(self, enable):
@@ -692,6 +720,8 @@ class Hardware(BaseHardware):
       if dt > 0.300:
         print("ERROR: Hermes-Lite write queue timeout, queue 0x%x 0x%x 0x%x 0x%x 0x%x" % tuple(self.pc2hermeslitewritequeue[0:5]))
         return
+    if qlen <= 0:	# Do not add to queue, just finish last write
+      return
     ## Send next write(s)
     QS.pc_to_hermeslite_writequeue(self.pc2hermeslitewritequeue)
     QS.set_hermeslite_writepointer(qlen)
@@ -855,6 +885,29 @@ class Hardware(BaseHardware):
       else:
         if DEBUG: print("EEPROM read {0:#x} from address {1:#x}".format(v0,addr))
       return v0
+  def WriteI2C(self, bus, i2caddr, control, value):
+    # bus is 0x7c or 0x7d
+    self.pc2hermeslitewritequeue[0:5] = bus, 0x06, i2caddr, control, value
+    self.WriteQueue(1)
+    if DEBUG: print ("Write I2C bus 0x%X, i2caddr 0x%X, control 0x%X, value 0x%X" % (bus, i2caddr, control, value))
+  def ReadI2C(self, bus, i2caddr, control):
+    # bus is 0x7c or 0x7d
+    self.WriteQueue(0)		# Finish any writes
+    self.pc2hermeslitewritequeue[0:5] = bus, 0x07, i2caddr, control, 0
+    QS.clear_hermeslite_response()
+    self.WriteQueue(1)
+    for j in range(50):
+      time.sleep(0.001)
+      resp = QS.get_hermeslite_response()
+      if resp[0] != 0:
+        break
+    else:
+      if DEBUG:
+        print("ReadI2C timed out and did not return a value")
+      return None
+    resp[0] = (resp[0] >> 1) & 0x3F	# 6-bit bus in C0
+    if DEBUG: print ("Read  I2C bus 0x%X, 0x%X, 0x%X, 0x%X, 0x%X " % tuple(resp))
+    return resp
   def ProgramGateware(self, event):	# Program the Gateware (FPGA firmware) over Ethernet
     title = "Program the Gateware"
     main_frame = self.application.main_frame
