@@ -1385,7 +1385,7 @@ hot_key_ptt2 = wx.ACCEL_NORMAL
 ## hot_key_ptt_toggle	PTT key toggle, boolean
 # Set to True if you want PTT to remain on when you release the key.  A second key press will
 # then release PTT.  This is toggle mode.  If False, you must keep pressing the key, and releasing
-# it will release PTT.
+# it will release PTT. This also applies to the MIDI PTT control.
 # Changes are immediate (no need to restart).
 hot_key_ptt_toggle = False
 #hot_key_ptt_toggle = True
@@ -2301,10 +2301,8 @@ bandShortcuts = {'Audio':'', 'Aux1':'1', '160':'1', '80':'8', '60':'6', '40':'4'
 # the frequency displayed by Quisk.  For example, if you have a 2 meter transverter,
 # you may need to tune your hardware from 28 to 30 MHz to receive 144 to 146 MHz.
 # Enter the transverter offset in Hertz in this dictionary.  For this to work, your
-# hardware must support it.  Currently, the HiQSDR, SDR-IQ and SoftRock are supported.
-bandTransverterOffset = {
-#    '2': 144000000 - 28000000
-}
+# hardware must support it.  Currently, the HiQSDR, SDR-IQ and SoftRock are supported.  bandTransverterOffset = {'2': 144000000 - 28000000}
+bandTransverterOffset = {}
 
 
 
